# Arkouda Python Benchmarks

  * depending on your setup you may need to set `PYTHONPATH` environment variable to find the `arkouda.py` module
  * the `run_all.sh` script runs them against an `arkouda_server` running on `localhost:5555`
  * check the benchmark source for runtime options
